@@ -1,16 +1,15 @@
 package # Hide me
     TestApp::View::Email::Template;
-our $VERSION = '0.21_01';
 
 use strict;
 use base 'Catalyst::View::Email::Template';
 
 __PACKAGE__->config(
     sender => {
-        mailer => 'Test'
+        method => 'Test'
     },
     stash_key       => 'email',
-    template_prefix => '',
+    template_prefix => ''
 );
 
 1;
